@@ -9,14 +9,14 @@
 #' @export
 #' @param x The output from [occ()] call, output from call to
 #' [occ2df()], or an occurrence ID as a occkey class.
-#' @param from (character) The data provider. One of gbif, bison, inat,
+#' @param from (character) The data provider. One of gbif, inat,
 #' or vertnet
 #' @return A list, with each slot named for the data source, and then
 #' within data sources is a slot for each taxon, named by it's occurrence ID.
 #'
 #' @examples \dontrun{
 #' spnames <- c('Accipiter striatus', 'Spinus tristis')
-#' out <- occ(query=spnames, from=c('gbif','bison'),
+#' out <- occ(query=spnames, from=c('gbif','idigbio'),
 #'    gbifopts=list(hasCoordinate=TRUE), limit=2)
 #' res <- occ2df(out)
 #' inspect(res)
@@ -55,7 +55,6 @@ inspect.occdat <- function(x, from="gbif") {
 inspect.occkey <- function(x, from="gbif"){
   switch(class(x)[1],
          gbifkey = as.gbif(x),
-         bisonkey = as.bison(x),
          idigbiokey = as.idigbio(x))
 }
 
@@ -66,7 +65,6 @@ make_df <- function(x){
     out[[ names(obj)[i] ]] <-
       switch(names(obj)[i],
              gbif = as.gbif(obj[[i]]),
-             bison = as.bison(obj[[i]]),
              idigbio = as.idigbio(obj[[i]])
       )
   }
