@@ -6,14 +6,13 @@ occ_loopfun <- function(x, y, s, p, z, hc, d, w, sources, ds) {
   # x = query; y = limit; s = start; p = page;
   # z = geometry; hc = has_coords; d = date; w = callopts
   gbif_res <- foo_gbif(sources, x, y, s, z, hc, d, w, ds$gbif)
-  bison_res <- foo_bison(sources, x, y, s, z, d, w, ds$bison)
   inat_res <- foo_inat(sources, x, y, p, z, hc, d, w, ds$inat)
   ebird_res <- foo_ebird(sources, x, y, w, ds$ebird)
   vertnet_res <- foo_vertnet(sources, x, y, hc, d, w, ds$vertnet)
   idigbio_res <- foo_idigbio(sources, x, y, s, z, hc, d, w, ds$idigbio)
   obis_res <- foo_obis(sources, x, y, s, z, hc, d, w, ds$obis)
   ala_res <- foo_ala(sources, x, y, s, z, hc, d, w, ds$ala)
-  list(gbif = gbif_res, bison = bison_res, inat = inat_res, ebird = ebird_res,
+  list(gbif = gbif_res, inat = inat_res, ebird = ebird_res,
        vertnet = vertnet_res,
        idigbio = idigbio_res, obis = obis_res, ala = ala_res)
 }
@@ -25,13 +24,11 @@ occ_loopids <- function(x, y, s, p, z, hc, d, w, sources, ds) {
          call. = FALSE)
   if (inherits(x, 'gbifid')) {
     gbif_res <- foo_gbif(sources, x, y, s, z, hc, d, w, ds$gbif)
-    bison_res <- empty_time_data()
   } else if (inherits(x, 'tsn')) {
-    bison_res <- foo_bison(sources, x, y, s, z, d, w, ds$bison)
     gbif_res <- empty_time_data()
+    warning("bison no longer supported", call. = FALSE)
   }
   list(gbif = gbif_res,
-       bison = bison_res,
        inat = empty_time_data(),
        ebird = empty_time_data(),
        vertnet = empty_time_data(),
