@@ -28,15 +28,11 @@ test_that("has_coords works with all data sources as planned", {
       has_coords = TRUE)
     gg <- occ('Accipiter striatus', from = 'ebird', limit = 5,
       has_coords = TRUE)
-    hh <- occ('Accipiter striatus', from = 'bison', limit = 5,
-      has_coords = TRUE)
   }, preserve_exact_body_bytes = TRUE)
 
 
   expect_is(dd, "occdat")
-  # expect_is(ff, "occdat")
   expect_is(gg, "occdat")
-  expect_is(hh, "occdat")
 
   expect_false(anyNA(dd$inat$data[[1]]$longitude))
   expect_false(anyNA(dd$inat$data[[1]]$latitude))
